import { CellAdapter } from './CellAdapter';
export interface ICellState {
    source?: string;
    outputsCount?: number;
    adapter?: CellAdapter;
    isKernelSessionAvailable?: boolean;
    isExecuting?: boolean;
}
export interface ICellsState {
    cells: Map<string, ICellState>;
    areAllKernelSessionsReady: boolean;
    isAnyCellExecuting: boolean;
}
export type CellsState = ICellsState & {
    setCells: (cells: Map<string, ICellState>) => void;
    setSource: (id: string, source: string) => void;
    setOutputsCount: (id: string, outputsCount: number) => void;
    setKernelSessionAvailable: (id: string, kernelAvailable: boolean) => void;
    setAdapter: (id: string, adapter?: CellAdapter) => void;
    getAdapter: (id: string) => CellAdapter | undefined;
    getSource: (id: string) => string | undefined;
    getOutputsCount: (id: string) => number | undefined;
    isKernelSessionAvailable: (id: string) => boolean | undefined;
    execute: (id?: string) => void;
    setIsExecuting: (id: string, isExecuting: boolean) => void;
};
/**
 * Check if any cell is currently executing
 */
export declare const isAnyCellRunning: (cells: Map<string, ICellState>) => boolean;
export declare const cellsStore: import("zustand").StoreApi<CellsState>;
export declare function useCellsStore(): CellsState;
export declare function useCellsStore<T>(selector: (state: CellsState) => T): T;
export default useCellsStore;
