/*
 * Copyright (c) 2021-2023 Datalayer, Inc.
 *
 * MIT License
 */
import { Widget } from '@lumino/widgets';
import { ManagerBase } from '@jupyter-widgets/base-manager';
import * as base from '@jupyter-widgets/base';
import * as controls from '@jupyter-widgets/controls';
export class IPyWidgetsViewManager extends ManagerBase {
    el;
    constructor(el) {
        super();
        this.el = el;
    }
    async loadClass(className, moduleName, moduleVersion) {
        return new Promise((resolve, reject) => {
            if (moduleName === '@jupyter-widgets/controls') {
                resolve(controls);
            }
            else if (moduleName === '@jupyter-widgets/base') {
                resolve(base);
            }
            else {
                const fallback = function (err) {
                    const failedId = err.requireModules && err.requireModules[0];
                    if (failedId) {
                        console.log(`Falling back to jsDelivr for ${moduleName}@${moduleVersion}`);
                        window.require([
                            `https://cdn.jsdelivr.net/npm/${moduleName}@${moduleVersion}/dist/index.js`,
                        ], resolve, reject);
                    }
                    else {
                        throw err;
                    }
                };
                window.require([`${moduleName}.js`], resolve, fallback);
            }
        }).then((module) => {
            if (module[className]) {
                return module[className];
            }
            else {
                return Promise.reject(`Class ${className} not found in module ${moduleName}@${moduleVersion}`);
            }
        });
    }
    async display_view(view) {
        // eslint-disable-next-line @typescript-eslint/no-this-alias
        const that = this;
        return Promise.resolve(view).then(view => {
            Widget.attach(view.luminoWidget, that.el);
            return view;
        });
    }
    _get_comm_info() {
        return Promise.resolve({});
    }
    _create_comm() {
        return Promise.reject('no comms available');
    }
}
export default IPyWidgetsViewManager;
//# sourceMappingURL=IPyWidgetsViewManager.js.map