import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
/*
 * Copyright (c) 2021-2023 Datalayer, Inc.
 *
 * MIT License
 */
import { useState } from 'react';
import { createRoot } from 'react-dom/client';
import { Box, Heading, Textarea, Button } from '@primer/react';
import { useJupyter } from '../jupyter/JupyterContext';
import { JupyterReactTheme } from '../theme/JupyterReactTheme';
import KernelProgressBar from './../components/kernel/KernelProgressBar';
export const KernelExecuteView = () => {
    const { defaultKernel: kernel } = useJupyter();
    const [running, setRunning] = useState(false);
    const [code, setCode] = useState('');
    const [result, setResult] = useState();
    const handleChange = (event) => {
        setCode(event.target.value);
    };
    const exec = () => {
        setRunning(true);
        setResult('');
        kernel?.execute(code)?.result
            .then((result) => {
            setResult(result);
        })
            .catch((error) => {
            console.log('Error', error);
            setResult(error);
        })
            .finally(() => {
            setRunning(false);
        });
    };
    const interrupt = () => {
        kernel?.interrupt();
    };
    return (_jsxs(Box, { m: 3, children: [_jsx(Heading, { children: "Wait on code execution" }), _jsxs(Box, { children: [_jsx(Textarea, { placeholder: "Enter some code, e.g. print('1+1'), and click on the Execute button.", onChange: handleChange, value: code }), _jsxs(Box, { mt: 3, display: "flex", children: [_jsx(Box, { children: _jsx(Button, { disabled: !kernel || running, onClick: exec, variant: !kernel || running ? 'default' : 'primary', children: "Execute" }) }), _jsx(Box, { ml: 3, children: _jsx(Button, { disabled: !running, onClick: interrupt, variant: "danger", children: "Interrupt" }) })] })] }), running && (_jsx(Box, { mt: 3, children: _jsx(KernelProgressBar, {}) })), result && (_jsxs(Box, { mt: 3, children: [_jsx(Heading, { as: "h3", children: "Result" }), _jsx(Box, { children: _jsx("pre", { children: result }) })] }))] }));
};
const KernelExecute = () => {
    return (_jsx(JupyterReactTheme, { children: _jsx(KernelExecuteView, {}) }));
};
const div = document.createElement('div');
document.body.appendChild(div);
const root = createRoot(div);
root.render(_jsx(KernelExecute, {}));
//# sourceMappingURL=KernelExecute.js.map