import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
/*
 * Copyright (c) 2021-2023 Datalayer, Inc.
 *
 * MIT License
 */
import { useState } from 'react';
import { ActionMenu, Button, Box } from '@primer/react';
import { ChevronRightIcon, XIcon, ChevronUpIcon, ChevronDownIcon, SquareIcon, } from '@primer/octicons-react';
import { CellMetadataEditor } from '../../components/notebook/cell/metadata';
import { useNotebookStore } from '../../components/notebook';
import { DATALAYER_CELL_SIDEBAR_CLASS_NAME } from '../../components/notebook/cell/sidebar/CellSidebarWidget';
export const CellSidebarSource = (props) => {
    const { notebookId, cellNodeId, nbgrader } = props;
    const notebookStore = useNotebookStore();
    const [visible, setVisible] = useState(false);
    const activeCell = notebookStore.selectActiveCell(notebookId);
    const layout = activeCell?.layout;
    if (layout) {
        const cellWidget = layout.widgets[0];
        if (cellWidget?.node.id === cellNodeId) {
            if (!visible) {
                setVisible(true);
            }
        }
        if (cellWidget?.node.id !== cellNodeId) {
            if (visible) {
                setVisible(false);
            }
        }
    }
    if (!visible) {
        return _jsx("div", {});
    }
    return activeCell ? (_jsxs(Box, { className: DATALAYER_CELL_SIDEBAR_CLASS_NAME, sx: {
            '& p': {
                marginBottom: '0 !important',
            },
        }, children: [_jsx(Box, { children: _jsx(Button, { leadingVisual: ChevronRightIcon, variant: "invisible", size: "small", onClick: (e) => {
                        e.preventDefault();
                        notebookStore.run(notebookId);
                    }, children: "Run" }) }), _jsx(Box, { children: _jsx(Button, { leadingVisual: ChevronUpIcon, variant: "invisible", size: "small", onClick: (e) => {
                        e.preventDefault();
                        notebookStore.insertAbove({
                            id: notebookId,
                            cellType: 'code',
                            source: "print('Hello 🪐 ⚛️ Jupyter React, I have been inserted up ⬆️.')",
                        });
                    }, children: "Code (with source)" }) }), _jsx(Box, { children: _jsx(Button, { leadingVisual: ChevronUpIcon, variant: "invisible", size: "small", onClick: (e) => {
                        e.preventDefault();
                        notebookStore.insertAbove({
                            id: notebookId,
                            cellType: 'markdown',
                        });
                    }, children: "Markdown" }) }), _jsx(Box, { children: activeCell.model.type === 'code' ? (_jsx(Button, { leadingVisual: SquareIcon, variant: "invisible", size: "small", onClick: (e) => {
                        e.preventDefault();
                        notebookStore.changeCellType({
                            id: notebookId,
                            cellType: 'markdown',
                        });
                    }, children: "To Markdown" })) : (_jsx(Button, { leadingVisual: SquareIcon, variant: "invisible", size: "small", onClick: (e) => {
                        e.preventDefault();
                        notebookStore.changeCellType({
                            id: notebookId,
                            cellType: 'code',
                        });
                    }, children: "To Code" })) }), _jsx(Box, { children: _jsx(Button, { leadingVisual: ChevronDownIcon, variant: "invisible", size: "small", onClick: (e) => {
                        e.preventDefault();
                        notebookStore.insertBelow({
                            id: notebookId,
                            cellType: 'markdown',
                        });
                    }, children: "Markdown" }) }), _jsx(Box, { children: _jsx(Button, { leadingVisual: ChevronDownIcon, variant: "invisible", size: "small", onClick: (e) => {
                        e.preventDefault();
                        notebookStore.insertBelow({
                            id: notebookId,
                            cellType: 'code',
                            source: "print('Hello 🪐 ⚛️ Jupyter React, I have been inserted down ⬇️.')",
                        });
                    }, children: "Code (with source)" }) }), _jsx(Box, { children: _jsx(Button, { leadingVisual: XIcon, variant: "invisible", size: "small", onClick: (e) => {
                        e.preventDefault();
                        notebookStore.delete(notebookId);
                    }, children: "Delete" }) }), nbgrader && (_jsx(ActionMenu, { children: _jsx(CellMetadataEditor, { notebookId: notebookId, cell: activeCell, nbgrader: nbgrader }) }))] })) : (_jsx(_Fragment, {}));
};
export default CellSidebarSource;
//# sourceMappingURL=CellSidebarSource.js.map