/*
 * Copyright (c) 2021-2023 Datalayer, Inc.
 *
 * MIT License
 */
import { createStore } from 'zustand/vanilla';
import { useStore } from 'zustand';
export var ExecutionPhase;
(function (ExecutionPhase) {
    ExecutionPhase["ready_to_run"] = "READY_TO_RUN";
    ExecutionPhase["running"] = "RUNNING";
    ExecutionPhase["completed"] = "COMPLETED";
    ExecutionPhase["completed_with_error"] = "COMPLETED_WITH_ERROR";
    ExecutionPhase["completed_with_warning"] = "COMPLETED_WITH_WARNING";
})(ExecutionPhase || (ExecutionPhase = {}));
export const kernelsStore = createStore((set, get) => ({
    kernels: new Map(),
    getExecutionState: (id) => {
        return get().kernels.get(id)?.executionState;
    },
    setExecutionState: (id, executionState) => {
        const kernels = get().kernels;
        const k = kernels.get(id);
        if (k) {
            k.executionState = executionState;
        }
        else {
            kernels.set(id, {
                id,
                executionState: executionState
            });
        }
        set((state) => ({ kernels }));
    },
    getExecutionPhase: (id) => {
        return get().kernels.get(id)?.executionPhase;
    },
    setExecutionPhase: (id, executionPhase) => {
        const kernels = get().kernels;
        const k = kernels.get(id);
        if (k) {
            k.executionPhase = executionPhase;
        }
        else {
            kernels.set(id, {
                id,
                executionPhase,
            });
        }
        set((state) => ({ kernels }));
    },
}));
export function useKernelsStore(selector) {
    return useStore(kernelsStore, selector);
}
export default useKernelsStore;
//# sourceMappingURL=KernelState.js.map